@@ -59,10 +59,10 @@ def get_default_delete_local_copy():
 
 class GCSTaskHandler(FileTaskHandler, LoggingMixin):
     """
-    GCSTaskHandler is a python log handler that handles and reads
-    task instance logs. It extends airflow FileTaskHandler and
-    uploads to and reads from GCS remote storage. Upon log reading
-    failure, it reads from host machine's local disk.
+    GCSTaskHandler is a python log handler that handles and reads task instance logs.
+
+    It extends airflow FileTaskHandler and uploads to and reads from GCS remote
+    storage. Upon log reading failure, it reads from host machine's local disk.
 
     :param base_log_folder: Base log folder to place logs.
     :param gcs_log_folder: Path to a remote location where logs will be saved. It must have the prefix
@@ -209,6 +209,7 @@ class GCSTaskHandler(FileTaskHandler, LoggingMixin):
     def _read(self, ti, try_number, metadata=None):
         """
         Read logs of given task instance and try_number from GCS.
+
         If failed, read the log from task instance host machine.
 
         todo: when min airflow version >= 2.6, remove this method
@@ -231,8 +232,7 @@ class GCSTaskHandler(FileTaskHandler, LoggingMixin):
 
     def gcs_write(self, log, remote_log_location) -> bool:
         """
-        Writes the log to the remote_log_location and return `True` when done. Fails silently
-         and return `False` if no log was created.
+        Write the log to the remote location and return `True`; fail silently and return `False` on error.
 
         :param log: the log to write to the remote_log_location
         :param remote_log_location: the log's location in remote storage
