@@ -678,7 +678,9 @@ class PubSubPublishMessageOperator(GoogleCloudBaseOperator):
 
 
 class PubSubPullOperator(GoogleCloudBaseOperator):
-    """Pulls messages from a PubSub subscription and passes them through XCom.
+    """
+    Pulls messages from a PubSub subscription and passes them through XCom.
+
     If the queue is empty, returns empty list - never waits for messages.
     If you do need to wait, please use :class:`airflow.providers.google.cloud.sensors.PubSubPullSensor`
     instead.
@@ -781,6 +783,7 @@ class PubSubPullOperator(GoogleCloudBaseOperator):
     ) -> list:
         """
         This method can be overridden by subclasses or by `messages_callback` constructor argument.
+
         This default implementation converts `ReceivedMessage` objects into JSON-serializable dicts.
 
         :param pulled_messages: messages received from the topic.
