@@ -15,10 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains Azure Data Lake Storage to
-Google Cloud Storage operator.
-"""
+"""This module contains Azure Data Lake Storage to Google Cloud Storage operator."""
+
 from __future__ import annotations
 
 import os
